.. image:: ../../images/logo.png

-------------------------------------

NetworkFitter
------------------
.. autoclass:: fracability.operations.Statistics.NetworkFitter
    :members:
    :inherited-members:
    :undoc-members: